import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../stores/DashboardComponentStore";
import {Table, TableBody, TableCell, TableHead, TableRow, Toolbar, Typography} from "@material-ui/core";
import {InputField, useReadonlyContext} from "@rx-suite/ui";
import {t} from "@lingui/macro";

export type GoalSetterProps = {
    component: DashboardComponentModel
}

export const GoalSetter: React.FunctionComponent<GoalSetterProps> = observer(({component}) => {
    const readOnly = useReadonlyContext();
    const targets = component.targetIds;
    if (targets.length === 0) {
        return null;
    }
    const hasDescription = targets.some((t: string) => component.targetParameterProp(t, 'description'))
    return <>
        <Toolbar><Typography variant={'h4'}>{t`Goals`}</Typography></Toolbar>
        <Table>
            <TableHead>
                <TableRow>
                    <TableCell>{t`Metric`}</TableCell>
                    {hasDescription && <TableCell>{t`Description`}</TableCell>}
                    <TableCell>{t`Goal`}</TableCell>
                </TableRow>
            </TableHead>
            <TableBody>
                {
                    targets.map((target: string) => {
                        return <TableRow key={target}>
                            <TableCell><Typography
                                variant={'subtitle2'}>{component.targetParameterName(target)}</Typography></TableCell>
                            {hasDescription && <TableCell><Typography
                                variant={'subtitle2'}>{component.targetParameterProp(target, 'description')}</Typography></TableCell>}
                            <TableCell><InputField label={t`Goal`}
                                                   name={`display_options.goals.${target}`}
                                                   value={((component.viewModel.display_options || {}).goals || {})[target] || ''}
                                                   disabled={readOnly}
                                                   type={'number'}
                                                   onChange={component.handleChange}/></TableCell>
                        </TableRow>
                    })}
            </TableBody>
        </Table>
    </>
});