import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../stores/DashboardComponentStore";
import {SelectField, useReadonlyContext} from "@rx-suite/ui";
import {t} from "@lingui/macro";

export type TitleOptionsFieldProps = {
    component: DashboardComponentModel
}

export const TitleOptionsField: React.FunctionComponent<TitleOptionsFieldProps> = observer(({component}) => {
    const readOnly = useReadonlyContext();
    React.useEffect(() => {
        if (((component.viewModel.display_options || {}).title || {}).position === undefined) {
            component.nestedAssignment(`display_options.title.position`, 'top-left');
        }
    }, [component])
    const label = t`Display Title`;
    return <SelectField label={label}
                        name={`display_options.title.position`}
                        options={[
                            {label: t`Left`, value: 'top-left'},
                            {label: t`Middle`, value: 'top-middle'},
                            {label: t`Right`, value: 'top-right'},
                            {label: t`None`, value: 'omit'},
                        ]}
                        value={((component.viewModel.display_options || {}).title || {}).position || ''}
                        disabled={readOnly}
                        onChange={component.handleSelectChange}
                        hint={{
                            title: label,
                            text: t`Choose where to put the component name, or omit it entirely`
                        }}
    />

});