import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../stores/DashboardComponentStore";
import {BarChart} from "@rx-suite/ui";

export type DashboardComponentBarChartProps = {
    component: DashboardComponentModel
};

export const DashboardComponentBarChart: React.FunctionComponent<DashboardComponentBarChartProps> = observer(({component}) => {
    const series = component.viewModel.data.series || [];
    const labels = (component.viewModel.data.categories || []).map((c: { name: string }) => c.name);

    if (component.isNew) {
        const fakeSeries = [{data: [Math.ceil(Math.random() * 10), Math.ceil(Math.random() * 10), Math.ceil(Math.random() * 10), Math.ceil(Math.random() * 10), Math.ceil(Math.random() * 10)]}]
        return <BarChart series={fakeSeries}
                         key={JSON.stringify(fakeSeries)}
                         horizontal={!!((component.viewModel.display_options || {}).bar || {}).horizontal}
                         options={{
                             ...component.graphOptions,
                             labels: ['A', 'B', 'C', 'D', 'E'],
                             legend: {show: false},
                             colors: ['#DCDCDC', "#C0C0C0", "#808080", "#606060", "#404040"]
                         }}/>
    } else {
        return <BarChart series={series}
                         horizontal={!!((component.viewModel.display_options || {}).bar || {}).horizontal}
                         options={{
                             ...component.graphOptions,
                             labels: labels,
                             legend: {show: series.length > 1}
                         }}/>;
    }
});
