import * as React from 'react';
import {observer, Observer} from "mobx-react-lite";
import {DashboardModel, DashboardStore} from "../../stores/DashboardStore";
import ReactTable, {Column, RowInfo} from "react-table";
import {t} from "@lingui/macro";
import {Add, Remove} from '@material-ui/icons';
import {ButtonField, makeColumn} from "@rx-suite/ui";
import {IconButton, Typography} from "@material-ui/core";
import {DashboardGroupModel} from "../../stores/DashboardGroupStore";
import {DashboardComponentModel} from "../../stores/DashboardComponentStore";

export const AddDashboardTable: React.FunctionComponent<{ group: DashboardGroupModel, openForm: () => void }> = observer(({
                                                                                                                              group,
                                                                                                                              openForm
                                                                                                                          }) => {
    const store = DashboardStore;
    React.useEffect(() => {
        store.getTableData();
    });
    const columns = React.useMemo(() => [
        makeColumn('name', t`Name`, "string"),
        makeColumn('desc', t`Description`, "string", val => {
            return (val || '').split("\n").map((v: string) => <React.Fragment key={v}>{v}<br/></React.Fragment>)
        }),
        {
            accessor: (d: DashboardModel) => d,
            id: '_components',
            Cell: (cellInfo: { value: DashboardModel }) => {
                if (!cellInfo.value || !cellInfo.value.getId) {
                    return null;
                }
                return <div>
                    {cellInfo.value.components.map((c: DashboardComponentModel | null) => c ? c.name : null).filter(c => c).join(', ')}
                </div>;
            },
            Header: t`Components`,
            sortable: false,
            filterable: false
        },
        {
            accessor: (d: DashboardModel) => d,
            id: '_actions',
            style: {textAlign: "center"},
            width: 100,
            Cell: (cellInfo: { value: DashboardModel }) => {
                if (!cellInfo.value || !cellInfo.value.getId) {
                    return null;
                }
                return <Observer>
                    {() => group.hasDashboard(cellInfo.value) ?
                        <IconButton color={"secondary"} onClick={() => group.removeDashboard(cellInfo.value)}>
                            <Remove/>
                        </IconButton>
                        : <IconButton color={"secondary"} onClick={() => group.addDashboard(cellInfo.value)}>
                            <Add/>
                        </IconButton>
                    }</Observer>

            },
            sortable: false,
            filterable: false,
            Footer: () => {
            } // trick footer into appearing
        }
    ], [group]);
    return (
        <>
            <Typography variant={"h5"}>{t`Add Existing Dashboard`}</Typography>
            <ReactTable data={store.tableData || []}
                        className={'-striped -highlight'}
                        resolveData={data => data.map(r => r || {})}
                        pages={store.pages}
                        columns={columns}
                        loading={store.isLoading}
                        defaultPageSize={5}
                        manual
                        onFetchData={(state) => {
                            store.setFetchParams({
                                page: state.page,
                                limit: state.pageSize,
                                sorted: state.sorted,
                                filtered: state.filtered
                            })
                        }}
                        getTdProps={(_: any, rowInfo: RowInfo | undefined, column: Column | undefined) => {
                            if (rowInfo && rowInfo.original && rowInfo.original.getId && (column || {}).id !== '_actions') {
                                return {
                                    onClick: () => {
                                        if (group.hasDashboard(rowInfo.original)) {
                                            group.removeDashboard(rowInfo.original)
                                        } else {
                                            group.addDashboard(rowInfo.original)
                                        }
                                    },
                                    style: {cursor: 'pointer'}
                                }
                            }
                            return {};
                        }}
                        TfootComponent={() => <ButtonField
                            text={t`Make New Dashboard`}
                            startIcon={<Add/>}
                            onClick={openForm}
                        />}
            />
        </>
    )
});
