import * as React from 'react';
import {observer, Observer} from "mobx-react-lite";
import {DashboardModel} from "../../stores/DashboardStore";
import ReactTable, {Column, RowInfo} from "react-table";
import {DashboardComponentModel, DashboardComponentStore} from "../../stores/DashboardComponentStore";
import {t} from "@lingui/macro";
import {Add, Remove} from '@material-ui/icons';
import {makeColumn} from "@rx-suite/ui";
import {IconButton} from "@material-ui/core";
import {DashboardComponent} from "../dashboard_components/renderers/DashboardComponent";
import {makeStyles} from "@material-ui/core/styles";

const useStyles = makeStyles(theme => ({
    previewCellOuter: {
        boxSizing: 'border-box',
        width: '100%',
        position: 'relative',
        paddingTop: '50%'
    },
    previewCellInner: {
        position: 'absolute',
        top: 0,
        left: 0,
        height: '100%',
        width: '100%',
    }
}));

export const AddComponentTable: React.FunctionComponent<{ dashboard: DashboardModel, openForm: () => void }> = observer(({
                                                                                                                             dashboard,
                                                                                                                             openForm
                                                                                                                         }) => {
    const store = DashboardComponentStore;
    const classes = useStyles();
    React.useEffect(() => {
        store.getTableData();
    });
    const columns = React.useMemo(() => [
        makeColumn('name', t`Name`, "string"),
        makeColumn('dashboard_target.name', t`Target`, "string"),
        makeColumn('dashboard_target.module_name', t`Module`, "string"),
        makeColumn('desc', t`Description`, "string", val => {
            return (val || '').split("\n").map((v: string) => <React.Fragment key={v}>{v}<br/></React.Fragment>)
        }),
        {
            accessor: (d: DashboardComponentModel) => d,
            id: '_preview',
            style: {textAlign: "center"},
            width: 450,
            Cell: (cellInfo: { value: DashboardComponentModel }) => {
                if (!cellInfo.value || !cellInfo.value.getId) {
                    return null;
                }
                return <div className={classes.previewCellOuter}>
                    <div className={classes.previewCellInner}><DashboardComponent component={cellInfo.value}/></div>
                </div>;
            },
            Header: t`Preview`,
            sortable: false,
            filterable: false
        },
        {
            accessor: (d: DashboardComponentModel) => d,
            id: '_actions',
            style: {textAlign: "center"},
            width: 100,
            Cell: (cellInfo: { value: DashboardComponentModel }) => {
                if (!cellInfo.value || !cellInfo.value.getId) {
                    return null;
                }
                return <Observer>
                    {() => dashboard.hasComponent(cellInfo.value) ?
                        <IconButton color={"secondary"} onClick={() => dashboard.removeComponent(cellInfo.value)}>
                            <Remove/>
                        </IconButton>
                        : <IconButton color={"secondary"} onClick={() => dashboard.addComponent(cellInfo.value)}>
                            <Add/>
                        </IconButton>
                    }</Observer>

            },
            sortable: false,
            filterable: false
        }
    ], [dashboard]);
    return (
        <ReactTable data={store.tableData || []}
                    className={'-striped -highlight'}
                    resolveData={data => data.map(r => r || {})}
                    pages={store.pages}
                    columns={columns}
                    loading={store.isLoading}
                    defaultPageSize={5}
                    manual
                    getTdProps={(_: any, rowInfo: RowInfo | undefined, column: Column | undefined) => {
                        if (rowInfo && rowInfo.original && rowInfo.original.getId && (column || {}).id !== '_actions') {
                            return {
                                onClick: () => {
                                    if (dashboard.hasComponent(rowInfo.original)) {
                                        dashboard.removeComponent(rowInfo.original)
                                    } else {
                                        dashboard.addComponent(rowInfo.original)
                                    }
                                },
                                style: {cursor: 'pointer'}
                            }
                        }
                        return {};
                    }}
                    onFetchData={(state) => {
                        store.setFetchParams({
                            page: state.page,
                            limit: state.pageSize,
                            sorted: state.sorted,
                            filtered: state.filtered
                        })
                    }}
        />
    )
});
